#!/usr/bin/perl -w
# Copyright (c) 2011-2018 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

$Data{'langfam'}{'link'} = [];

################################################################################

$Data{'langfam'}{'iso'}{'orig'}{'name'} = {
   "Creoles and pidgins, English‑based"  => "Creoles and pidgins, English-based",
   "Creoles and pidgins, French‑based"   => "Creoles and pidgins, French-based",
};

$Data{'langfam'}{'iso'}{'ignore'} = {
};

1;

# Local Variables:
# mode: cperl
# indent-tabs-mode: nil
# cperl-indent-level: 3
# cperl-continued-statement-offset: 2
# cperl-continued-brace-offset: 0
# cperl-brace-offset: 0
# cperl-brace-imaginary-offset: 0
# cperl-label-offset: 0
# End:

