package #
Locale::Codes::LangVar_Codes;

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'harvest_data' is run.
#    Generated on: Wed May 30 10:21:59 EDT 2018

use strict;
require 5.006;
use warnings;
use utf8;

our($VERSION);
$VERSION='3.57';

$Locale::Codes::Data{'langvar'}{'id'} = '0098';

$Locale::Codes::Data{'langvar'}{'id2names'} = {
   q(0001) => [
      q(Late Middle French (to 1606)),
      ],
   q(0002) => [
      q(Early Modern French),
      ],
   q(0003) => [
      q(Traditional German orthography),
      ],
   q(0004) => [
      q("Academic" ("governmental") variant of Belarusian as codified in 1959),
      ],
   q(0005) => [
      q(Standardized Resian orthography),
      ],
   q(0006) => [
      q(German orthography of 1996),
      ],
   q(0007) => [
      q(Orthographic formulation of 1943 - Official in Brazil (Formulario Ortografico de 1943 - Oficial no Brasil)),
      ],
   q(0008) => [
      q(ALA-LC Romanization, 1997 edition),
      ],
   q(0009) => [
      q(Aluku dialect),
      q(Boni dialect),
      ],
   q(0010) => [
      q(Akuapem Twi),
      ],
   q(0011) => [
      q(Portuguese Language Orthographic Agreement of 1990 (Acordo Ortografico da Lingua Portuguesa de 1990)),
      ],
   q(0012) => [
      q(Aranese),
      ],
   q(0013) => [
      q(Asante Twi),
      q(Ashanti Twi),
      ],
   q(0014) => [
      q(Auvergnat),
      ],
   q(0015) => [
      q(Unified Turkic Latin Alphabet (Historical)),
      ],
   q(0016) => [
      q(The Balanka dialect of Anii),
      ],
   q(0017) => [
      q(The Barlavento dialect group of Kabuverdianu),
      ],
   q(0018) => [
      q(Basic English),
      ],
   q(0019) => [
      q(Buddhist Hybrid Sanskrit),
      ],
   q(0020) => [
      q(Biscayan dialect of Basque),
      ],
   q(0021) => [
      q(The San Giorgio dialect of Resian),
      q(The Bila dialect of Resian),
      ],
   q(0022) => [
      q(Slovene in Bohoric alphabet),
      ],
   q(0023) => [
      q(Boontling),
      ],
   q(0024) => [
      q(Cisalpine),
      ],
   q(0025) => [
      q(Portuguese-Brazilian Orthographic Convention of 1945 (Convencao Ortografica Luso-Brasileira de 1945)),
      ],
   q(0026) => [
      q(Cornu-English),
      q(Cornish English),
      q(Anglo-Cornish),
      ],
   q(0027) => [
      q(Occitan variants of the Croissant area),
      ],
   q(0028) => [
      q(Slovene in Dajnko alphabet),
      ],
   q(0029) => [
      q(Serbian with Ekavian pronunciation),
      ],
   q(0030) => [
      q(Early Modern English (1500-1700)),
      ],
   q(0031) => [
      q(International Phonetic Alphabet),
      ],
   q(0032) => [
      q(Kirshenbaum Phonetic Alphabet),
      ],
   q(0033) => [
      q(North American Phonetic Alphabet),
      q(Americanist Phonetic Notation),
      ],
   q(0034) => [
      q(Uralic Phonetic Alphabet),
      ],
   q(0035) => [
      q(X-SAMPA transcription),
      ],
   q(0036) => [
      q(Gascon),
      ],
   q(0037) => [
      q(Classical Occitan orthography),
      ],
   q(0038) => [
      q(Italian-inspired Occitan orthography),
      ],
   q(0039) => [
      q(Mistralian or Mistralian-inspired Occitan orthography),
      ],
   q(0040) => [
      q(Hepburn romanization),
      ],
   q(0041) => [
      q(Norwegian in Hognorsk (High Norwegian) orthography),
      ],
   q(0042) => [
      q(Standard H-system orthographic fallback for spelling Esperanto),
      ],
   q(0043) => [
      q(Serbian with Ijekavian pronunciation),
      ],
   q(0044) => [
      q(Epic Sanskrit),
      ],
   q(0045) => [
      q(Bulgarian in 1899 orthography),
      ],
   q(0046) => [
      q(Jauer dialect of Romansh),
      ],
   q(0047) => [
      q(Jyutping Cantonese Romanization),
      ],
   q(0048) => [
      q(Common Cornish orthography of Revived Cornish),
      ],
   q(0049) => [
      q(The Kociewie dialect of Polish),
      ],
   q(0050) => [
      q(Standard Cornish orthography of Revived Cornish),
      q(Kernowek Standard),
      ],
   q(0051) => [
      q(Classical Sanskrit),
      ],
   q(0052) => [
      q(Limousin),
      ],
   q(0053) => [
      q(Languedocien),
      ],
   q(0054) => [
      q(The Lipovaz dialect of Resian),
      q(The Lipovec dialect of Resian),
      ],
   q(0055) => [
      q(Post-1917 Russian orthography),
      ],
   q(0056) => [
      q(Slovene in Metelko alphabet),
      ],
   q(0057) => [
      q(Monotonic Greek),
      ],
   q(0058) => [
      q(Ndyuka dialect),
      q(Aukan dialect),
      ],
   q(0059) => [
      q(Natisone dialect),
      q(Nadiza dialect),
      ],
   q(0060) => [
      q(Newfoundland English),
      ],
   q(0061) => [
      q(Nicard),
      ],
   q(0062) => [
      q(The Gniva dialect of Resian),
      q(The Njiva dialect of Resian),
      ],
   q(0063) => [
      q(Volapuk nulik),
      q(Volapuk perevidol),
      q(Volapuk nuladik),
      q(de Jong's Volapuk),
      q(New Volapuk),
      q(Revised Volapuk),
      q(Modern Volapuk),
      ],
   q(0064) => [
      q(The Oseacco dialect of Resian),
      q(The Osojane dialect of Resian),
      ],
   q(0065) => [
      q(Oxford English Dictionary spelling),
      ],
   q(0066) => [
      q(Pahawh Hmong Second Stage Reduced orthography),
      ],
   q(0067) => [
      q(Pahawh Hmong Third Stage Reduced orthography),
      ],
   q(0068) => [
      q(Pahawh Hmong Final Version orthography),
      ],
   q(0069) => [
      q(Pamaka dialect),
      ],
   q(0070) => [
      q(Petrine orthography),
      ],
   q(0071) => [
      q(Pinyin romanization),
      ],
   q(0072) => [
      q(Polytonic Greek),
      ],
   q(0073) => [
      q(Provencal),
      ],
   q(0074) => [
      q(Puter idiom of Romansh),
      ],
   q(0075) => [
      q(Volapuk rigik),
      q(Schleyer's Volapuk),
      q(Original Volapuk),
      q(Classic Volapuk),
      ],
   q(0076) => [
      q(Resian),
      q(Resianic),
      q(Rezijan),
      ],
   q(0077) => [
      q(Rumantsch Grischun),
      ],
   q(0078) => [
      q(Scottish Standard English),
      ],
   q(0079) => [
      q(Scouse),
      ],
   q(0080) => [
      q(Simplified form),
      ],
   q(0081) => [
      q(The Stolvizza dialect of Resian),
      q(The Solbica dialect of Resian),
      ],
   q(0082) => [
      q(The Sotavento dialect group of Kabuverdianu),
      ],
   q(0083) => [
      q(Spanglish),
      ],
   q(0084) => [
      q(Surmiran idiom of Romansh),
      ],
   q(0085) => [
      q(Sursilvan idiom of Romansh),
      ],
   q(0086) => [
      q(Sutsilvan idiom of Romansh),
      ],
   q(0087) => [
      q(Belarusian in Taraskievica orthography),
      ],
   q(0088) => [
      q(Unified Cornish orthography of Revived Cornish),
      ],
   q(0089) => [
      q(Unified Cornish Revised orthography of Revived Cornish),
      ],
   q(0090) => [
      q(Ulster dialect of Scots),
      ],
   q(0091) => [
      q(Unifon phonetic alphabet),
      ],
   q(0092) => [
      q(Vedic Sanskrit),
      ],
   q(0093) => [
      q(Valencian),
      ],
   q(0094) => [
      q(Vallader idiom of Romansh),
      ],
   q(0095) => [
      q(Vivaro-Alpine),
      ],
   q(0096) => [
      q(Wade-Giles romanization),
      ],
   q(0097) => [
      q(Standard X-system orthographic fallback for spelling Esperanto),
      ],
};

$Locale::Codes::Data{'langvar'}{'alias2id'} = {
   q("academic" ("governmental") variant of belarusian as codified in 1959) => [
      q(0004),
      q(0),
      ],
   q(akuapem twi) => [
      q(0010),
      q(0),
      ],
   q(ala-lc romanization, 1997 edition) => [
      q(0008),
      q(0),
      ],
   q(aluku dialect) => [
      q(0009),
      q(0),
      ],
   q(americanist phonetic notation) => [
      q(0033),
      q(1),
      ],
   q(anglo-cornish) => [
      q(0026),
      q(2),
      ],
   q(aranese) => [
      q(0012),
      q(0),
      ],
   q(asante twi) => [
      q(0013),
      q(0),
      ],
   q(ashanti twi) => [
      q(0013),
      q(1),
      ],
   q(aukan dialect) => [
      q(0058),
      q(1),
      ],
   q(auvergnat) => [
      q(0014),
      q(0),
      ],
   q(basic english) => [
      q(0018),
      q(0),
      ],
   q(belarusian in taraskievica orthography) => [
      q(0087),
      q(0),
      ],
   q(biscayan dialect of basque) => [
      q(0020),
      q(0),
      ],
   q(boni dialect) => [
      q(0009),
      q(1),
      ],
   q(boontling) => [
      q(0023),
      q(0),
      ],
   q(buddhist hybrid sanskrit) => [
      q(0019),
      q(0),
      ],
   q(bulgarian in 1899 orthography) => [
      q(0045),
      q(0),
      ],
   q(cisalpine) => [
      q(0024),
      q(0),
      ],
   q(classic volapuk) => [
      q(0075),
      q(3),
      ],
   q(classical occitan orthography) => [
      q(0037),
      q(0),
      ],
   q(classical sanskrit) => [
      q(0051),
      q(0),
      ],
   q(common cornish orthography of revived cornish) => [
      q(0048),
      q(0),
      ],
   q(cornish english) => [
      q(0026),
      q(1),
      ],
   q(cornu-english) => [
      q(0026),
      q(0),
      ],
   q(de jong's volapuk) => [
      q(0063),
      q(3),
      ],
   q(early modern english (1500-1700)) => [
      q(0030),
      q(0),
      ],
   q(early modern french) => [
      q(0002),
      q(0),
      ],
   q(epic sanskrit) => [
      q(0044),
      q(0),
      ],
   q(gascon) => [
      q(0036),
      q(0),
      ],
   q(german orthography of 1996) => [
      q(0006),
      q(0),
      ],
   q(hepburn romanization) => [
      q(0040),
      q(0),
      ],
   q(international phonetic alphabet) => [
      q(0031),
      q(0),
      ],
   q(italian-inspired occitan orthography) => [
      q(0038),
      q(0),
      ],
   q(jauer dialect of romansh) => [
      q(0046),
      q(0),
      ],
   q(jyutping cantonese romanization) => [
      q(0047),
      q(0),
      ],
   q(kernowek standard) => [
      q(0050),
      q(1),
      ],
   q(kirshenbaum phonetic alphabet) => [
      q(0032),
      q(0),
      ],
   q(languedocien) => [
      q(0053),
      q(0),
      ],
   q(late middle french (to 1606)) => [
      q(0001),
      q(0),
      ],
   q(limousin) => [
      q(0052),
      q(0),
      ],
   q(mistralian or mistralian-inspired occitan orthography) => [
      q(0039),
      q(0),
      ],
   q(modern volapuk) => [
      q(0063),
      q(6),
      ],
   q(monotonic greek) => [
      q(0057),
      q(0),
      ],
   q(nadiza dialect) => [
      q(0059),
      q(1),
      ],
   q(natisone dialect) => [
      q(0059),
      q(0),
      ],
   q(ndyuka dialect) => [
      q(0058),
      q(0),
      ],
   q(new volapuk) => [
      q(0063),
      q(4),
      ],
   q(newfoundland english) => [
      q(0060),
      q(0),
      ],
   q(nicard) => [
      q(0061),
      q(0),
      ],
   q(north american phonetic alphabet) => [
      q(0033),
      q(0),
      ],
   q(norwegian in hognorsk (high norwegian) orthography) => [
      q(0041),
      q(0),
      ],
   q(occitan variants of the croissant area) => [
      q(0027),
      q(0),
      ],
   q(original volapuk) => [
      q(0075),
      q(2),
      ],
   q(orthographic formulation of 1943 - official in brazil (formulario ortografico de 1943 - oficial no brasil)) => [
      q(0007),
      q(0),
      ],
   q(oxford english dictionary spelling) => [
      q(0065),
      q(0),
      ],
   q(pahawh hmong final version orthography) => [
      q(0068),
      q(0),
      ],
   q(pahawh hmong second stage reduced orthography) => [
      q(0066),
      q(0),
      ],
   q(pahawh hmong third stage reduced orthography) => [
      q(0067),
      q(0),
      ],
   q(pamaka dialect) => [
      q(0069),
      q(0),
      ],
   q(petrine orthography) => [
      q(0070),
      q(0),
      ],
   q(pinyin romanization) => [
      q(0071),
      q(0),
      ],
   q(polytonic greek) => [
      q(0072),
      q(0),
      ],
   q(portuguese language orthographic agreement of 1990 (acordo ortografico da lingua portuguesa de 1990)) => [
      q(0011),
      q(0),
      ],
   q(portuguese-brazilian orthographic convention of 1945 (convencao ortografica luso-brasileira de 1945)) => [
      q(0025),
      q(0),
      ],
   q(post-1917 russian orthography) => [
      q(0055),
      q(0),
      ],
   q(provencal) => [
      q(0073),
      q(0),
      ],
   q(puter idiom of romansh) => [
      q(0074),
      q(0),
      ],
   q(resian) => [
      q(0076),
      q(0),
      ],
   q(resianic) => [
      q(0076),
      q(1),
      ],
   q(revised volapuk) => [
      q(0063),
      q(5),
      ],
   q(rezijan) => [
      q(0076),
      q(2),
      ],
   q(rumantsch grischun) => [
      q(0077),
      q(0),
      ],
   q(schleyer's volapuk) => [
      q(0075),
      q(1),
      ],
   q(scottish standard english) => [
      q(0078),
      q(0),
      ],
   q(scouse) => [
      q(0079),
      q(0),
      ],
   q(serbian with ekavian pronunciation) => [
      q(0029),
      q(0),
      ],
   q(serbian with ijekavian pronunciation) => [
      q(0043),
      q(0),
      ],
   q(simplified form) => [
      q(0080),
      q(0),
      ],
   q(slovene in bohoric alphabet) => [
      q(0022),
      q(0),
      ],
   q(slovene in dajnko alphabet) => [
      q(0028),
      q(0),
      ],
   q(slovene in metelko alphabet) => [
      q(0056),
      q(0),
      ],
   q(spanglish) => [
      q(0083),
      q(0),
      ],
   q(standard cornish orthography of revived cornish) => [
      q(0050),
      q(0),
      ],
   q(standard h-system orthographic fallback for spelling esperanto) => [
      q(0042),
      q(0),
      ],
   q(standard x-system orthographic fallback for spelling esperanto) => [
      q(0097),
      q(0),
      ],
   q(standardized resian orthography) => [
      q(0005),
      q(0),
      ],
   q(surmiran idiom of romansh) => [
      q(0084),
      q(0),
      ],
   q(sursilvan idiom of romansh) => [
      q(0085),
      q(0),
      ],
   q(sutsilvan idiom of romansh) => [
      q(0086),
      q(0),
      ],
   q(the balanka dialect of anii) => [
      q(0016),
      q(0),
      ],
   q(the barlavento dialect group of kabuverdianu) => [
      q(0017),
      q(0),
      ],
   q(the bila dialect of resian) => [
      q(0021),
      q(1),
      ],
   q(the gniva dialect of resian) => [
      q(0062),
      q(0),
      ],
   q(the kociewie dialect of polish) => [
      q(0049),
      q(0),
      ],
   q(the lipovaz dialect of resian) => [
      q(0054),
      q(0),
      ],
   q(the lipovec dialect of resian) => [
      q(0054),
      q(1),
      ],
   q(the njiva dialect of resian) => [
      q(0062),
      q(1),
      ],
   q(the oseacco dialect of resian) => [
      q(0064),
      q(0),
      ],
   q(the osojane dialect of resian) => [
      q(0064),
      q(1),
      ],
   q(the san giorgio dialect of resian) => [
      q(0021),
      q(0),
      ],
   q(the solbica dialect of resian) => [
      q(0081),
      q(1),
      ],
   q(the sotavento dialect group of kabuverdianu) => [
      q(0082),
      q(0),
      ],
   q(the stolvizza dialect of resian) => [
      q(0081),
      q(0),
      ],
   q(traditional german orthography) => [
      q(0003),
      q(0),
      ],
   q(ulster dialect of scots) => [
      q(0090),
      q(0),
      ],
   q(unified cornish orthography of revived cornish) => [
      q(0088),
      q(0),
      ],
   q(unified cornish revised orthography of revived cornish) => [
      q(0089),
      q(0),
      ],
   q(unified turkic latin alphabet (historical)) => [
      q(0015),
      q(0),
      ],
   q(unifon phonetic alphabet) => [
      q(0091),
      q(0),
      ],
   q(uralic phonetic alphabet) => [
      q(0034),
      q(0),
      ],
   q(valencian) => [
      q(0093),
      q(0),
      ],
   q(vallader idiom of romansh) => [
      q(0094),
      q(0),
      ],
   q(vedic sanskrit) => [
      q(0092),
      q(0),
      ],
   q(vivaro-alpine) => [
      q(0095),
      q(0),
      ],
   q(volapuk nuladik) => [
      q(0063),
      q(2),
      ],
   q(volapuk nulik) => [
      q(0063),
      q(0),
      ],
   q(volapuk perevidol) => [
      q(0063),
      q(1),
      ],
   q(volapuk rigik) => [
      q(0075),
      q(0),
      ],
   q(wade-giles romanization) => [
      q(0096),
      q(0),
      ],
   q(x-sampa transcription) => [
      q(0035),
      q(0),
      ],
};

$Locale::Codes::Data{'langvar'}{'code2id'} = {
   q(alpha) => {
      q(1606nict) => [
         q(0001),
         q(0),
         ],
      q(1694acad) => [
         q(0002),
         q(0),
         ],
      q(1901) => [
         q(0003),
         q(0),
         ],
      q(1959acad) => [
         q(0004),
         q(0),
         ],
      q(1994) => [
         q(0005),
         q(0),
         ],
      q(1996) => [
         q(0006),
         q(0),
         ],
      q(abl1943) => [
         q(0007),
         q(0),
         ],
      q(akuapem) => [
         q(0010),
         q(0),
         ],
      q(alalc97) => [
         q(0008),
         q(0),
         ],
      q(aluku) => [
         q(0009),
         q(0),
         ],
      q(ao1990) => [
         q(0011),
         q(0),
         ],
      q(aranes) => [
         q(0012),
         q(0),
         ],
      q(asante) => [
         q(0013),
         q(0),
         ],
      q(auvern) => [
         q(0014),
         q(0),
         ],
      q(baku1926) => [
         q(0015),
         q(0),
         ],
      q(balanka) => [
         q(0016),
         q(0),
         ],
      q(barla) => [
         q(0017),
         q(0),
         ],
      q(basiceng) => [
         q(0018),
         q(0),
         ],
      q(bauddha) => [
         q(0019),
         q(0),
         ],
      q(biscayan) => [
         q(0020),
         q(0),
         ],
      q(biske) => [
         q(0021),
         q(0),
         ],
      q(bohoric) => [
         q(0022),
         q(0),
         ],
      q(boont) => [
         q(0023),
         q(0),
         ],
      q(cisaup) => [
         q(0024),
         q(0),
         ],
      q(colb1945) => [
         q(0025),
         q(0),
         ],
      q(cornu) => [
         q(0026),
         q(0),
         ],
      q(creiss) => [
         q(0027),
         q(0),
         ],
      q(dajnko) => [
         q(0028),
         q(0),
         ],
      q(ekavsk) => [
         q(0029),
         q(0),
         ],
      q(emodeng) => [
         q(0030),
         q(0),
         ],
      q(fonipa) => [
         q(0031),
         q(0),
         ],
      q(fonkirsh) => [
         q(0032),
         q(0),
         ],
      q(fonnapa) => [
         q(0033),
         q(0),
         ],
      q(fonupa) => [
         q(0034),
         q(0),
         ],
      q(fonxsamp) => [
         q(0035),
         q(0),
         ],
      q(gascon) => [
         q(0036),
         q(0),
         ],
      q(grclass) => [
         q(0037),
         q(0),
         ],
      q(grital) => [
         q(0038),
         q(0),
         ],
      q(grmistr) => [
         q(0039),
         q(0),
         ],
      q(hepburn) => [
         q(0040),
         q(0),
         ],
      q(hognorsk) => [
         q(0041),
         q(0),
         ],
      q(hsistemo) => [
         q(0042),
         q(0),
         ],
      q(ijekavsk) => [
         q(0043),
         q(0),
         ],
      q(itihasa) => [
         q(0044),
         q(0),
         ],
      q(ivanchov) => [
         q(0045),
         q(0),
         ],
      q(jauer) => [
         q(0046),
         q(0),
         ],
      q(jyutping) => [
         q(0047),
         q(0),
         ],
      q(kkcor) => [
         q(0048),
         q(0),
         ],
      q(kociewie) => [
         q(0049),
         q(0),
         ],
      q(kscor) => [
         q(0050),
         q(0),
         ],
      q(laukika) => [
         q(0051),
         q(0),
         ],
      q(lemosin) => [
         q(0052),
         q(0),
         ],
      q(lengadoc) => [
         q(0053),
         q(0),
         ],
      q(lipaw) => [
         q(0054),
         q(0),
         ],
      q(luna1918) => [
         q(0055),
         q(0),
         ],
      q(metelko) => [
         q(0056),
         q(0),
         ],
      q(monoton) => [
         q(0057),
         q(0),
         ],
      q(ndyuka) => [
         q(0058),
         q(0),
         ],
      q(nedis) => [
         q(0059),
         q(0),
         ],
      q(newfound) => [
         q(0060),
         q(0),
         ],
      q(nicard) => [
         q(0061),
         q(0),
         ],
      q(njiva) => [
         q(0062),
         q(0),
         ],
      q(nulik) => [
         q(0063),
         q(0),
         ],
      q(osojs) => [
         q(0064),
         q(0),
         ],
      q(oxendict) => [
         q(0065),
         q(0),
         ],
      q(pahawh2) => [
         q(0066),
         q(0),
         ],
      q(pahawh3) => [
         q(0067),
         q(0),
         ],
      q(pahawh4) => [
         q(0068),
         q(0),
         ],
      q(pamaka) => [
         q(0069),
         q(0),
         ],
      q(petr1708) => [
         q(0070),
         q(0),
         ],
      q(pinyin) => [
         q(0071),
         q(0),
         ],
      q(polyton) => [
         q(0072),
         q(0),
         ],
      q(provenc) => [
         q(0073),
         q(0),
         ],
      q(puter) => [
         q(0074),
         q(0),
         ],
      q(rigik) => [
         q(0075),
         q(0),
         ],
      q(rozaj) => [
         q(0076),
         q(0),
         ],
      q(rumgr) => [
         q(0077),
         q(0),
         ],
      q(scotland) => [
         q(0078),
         q(0),
         ],
      q(scouse) => [
         q(0079),
         q(0),
         ],
      q(simple) => [
         q(0080),
         q(0),
         ],
      q(solba) => [
         q(0081),
         q(0),
         ],
      q(sotav) => [
         q(0082),
         q(0),
         ],
      q(spanglis) => [
         q(0083),
         q(0),
         ],
      q(surmiran) => [
         q(0084),
         q(0),
         ],
      q(sursilv) => [
         q(0085),
         q(0),
         ],
      q(sutsilv) => [
         q(0086),
         q(0),
         ],
      q(tarask) => [
         q(0087),
         q(0),
         ],
      q(uccor) => [
         q(0088),
         q(0),
         ],
      q(ucrcor) => [
         q(0089),
         q(0),
         ],
      q(ulster) => [
         q(0090),
         q(0),
         ],
      q(unifon) => [
         q(0091),
         q(0),
         ],
      q(vaidika) => [
         q(0092),
         q(0),
         ],
      q(valencia) => [
         q(0093),
         q(0),
         ],
      q(vallader) => [
         q(0094),
         q(0),
         ],
      q(vivaraup) => [
         q(0095),
         q(0),
         ],
      q(wadegile) => [
         q(0096),
         q(0),
         ],
      q(xsistemo) => [
         q(0097),
         q(0),
         ],
      },
};

$Locale::Codes::Data{'langvar'}{'id2code'} = {
   q(alpha) => {
      q(0001) => q(1606nict),
      q(0002) => q(1694acad),
      q(0003) => q(1901),
      q(0004) => q(1959acad),
      q(0005) => q(1994),
      q(0006) => q(1996),
      q(0007) => q(abl1943),
      q(0008) => q(alalc97),
      q(0009) => q(aluku),
      q(0010) => q(akuapem),
      q(0011) => q(ao1990),
      q(0012) => q(aranes),
      q(0013) => q(asante),
      q(0014) => q(auvern),
      q(0015) => q(baku1926),
      q(0016) => q(balanka),
      q(0017) => q(barla),
      q(0018) => q(basiceng),
      q(0019) => q(bauddha),
      q(0020) => q(biscayan),
      q(0021) => q(biske),
      q(0022) => q(bohoric),
      q(0023) => q(boont),
      q(0024) => q(cisaup),
      q(0025) => q(colb1945),
      q(0026) => q(cornu),
      q(0027) => q(creiss),
      q(0028) => q(dajnko),
      q(0029) => q(ekavsk),
      q(0030) => q(emodeng),
      q(0031) => q(fonipa),
      q(0032) => q(fonkirsh),
      q(0033) => q(fonnapa),
      q(0034) => q(fonupa),
      q(0035) => q(fonxsamp),
      q(0036) => q(gascon),
      q(0037) => q(grclass),
      q(0038) => q(grital),
      q(0039) => q(grmistr),
      q(0040) => q(hepburn),
      q(0041) => q(hognorsk),
      q(0042) => q(hsistemo),
      q(0043) => q(ijekavsk),
      q(0044) => q(itihasa),
      q(0045) => q(ivanchov),
      q(0046) => q(jauer),
      q(0047) => q(jyutping),
      q(0048) => q(kkcor),
      q(0049) => q(kociewie),
      q(0050) => q(kscor),
      q(0051) => q(laukika),
      q(0052) => q(lemosin),
      q(0053) => q(lengadoc),
      q(0054) => q(lipaw),
      q(0055) => q(luna1918),
      q(0056) => q(metelko),
      q(0057) => q(monoton),
      q(0058) => q(ndyuka),
      q(0059) => q(nedis),
      q(0060) => q(newfound),
      q(0061) => q(nicard),
      q(0062) => q(njiva),
      q(0063) => q(nulik),
      q(0064) => q(osojs),
      q(0065) => q(oxendict),
      q(0066) => q(pahawh2),
      q(0067) => q(pahawh3),
      q(0068) => q(pahawh4),
      q(0069) => q(pamaka),
      q(0070) => q(petr1708),
      q(0071) => q(pinyin),
      q(0072) => q(polyton),
      q(0073) => q(provenc),
      q(0074) => q(puter),
      q(0075) => q(rigik),
      q(0076) => q(rozaj),
      q(0077) => q(rumgr),
      q(0078) => q(scotland),
      q(0079) => q(scouse),
      q(0080) => q(simple),
      q(0081) => q(solba),
      q(0082) => q(sotav),
      q(0083) => q(spanglis),
      q(0084) => q(surmiran),
      q(0085) => q(sursilv),
      q(0086) => q(sutsilv),
      q(0087) => q(tarask),
      q(0088) => q(uccor),
      q(0089) => q(ucrcor),
      q(0090) => q(ulster),
      q(0091) => q(unifon),
      q(0092) => q(vaidika),
      q(0093) => q(valencia),
      q(0094) => q(vallader),
      q(0095) => q(vivaraup),
      q(0096) => q(wadegile),
      q(0097) => q(xsistemo),
      },
};

1;
