#!/usr/bin/perl -w
# Copyright (c) 2011-2018 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

$Data{'langvar'}{'link'} = [];

################################################################################

$Data{'langvar'}{'iana'}{'orig'}{'name'} = {
   'Norwegian in Høgnorsk (High Norwegian) orthography' =>
       'Norwegian in Hognorsk (High Norwegian) orthography',
   "Volapük nulik"                     => "Volapuk nulik",
   "Volapük perevidöl"                 => "Volapuk perevidol",
   "Volapük nulädik"                   => "Volapuk nuladik",
   "de Jong's Volapük"                 => "de Jong's Volapuk",
   "New Volapük"                       => "New Volapuk",
   "Revised Volapük"                   => "Revised Volapuk",
   "Modern Volapük"                    => "Modern Volapuk",
   "Volapük rigik"                     => "Volapuk rigik",
   "Schleyer's Volapük"                => "Schleyer's Volapuk",
   "Original Volapük"                  => "Original Volapuk",
   "Classic Volapük"                   => "Classic Volapuk",
   "Slovene in Bohorič alphabet"       => "Slovene in Bohoric alphabet",
   "Orthographic formulation of 1943 - Official in Brazil (Formulário Ortográfico de 1943 - Oficial no Brasil)" =>
   "Orthographic formulation of 1943 - Official in Brazil (Formulario Ortografico de 1943 - Oficial no Brasil)",
   "Portugese Language Orthographic Agreement of 1990 (Acordo Ortográfico da Língua Portuguesa de 1990)" =>
   "Portugese Language Orthographic Agreement of 1990 (Acordo Ortografico da Lingua Portuguesa de 1990)",
   "Portuguese-Brazilian Orthographic Convention of 1945 (Convenção Ortográfica Luso-Brasileira de 1945)" =>
   "Portuguese-Brazilian Orthographic Convention of 1945 (Convencao Ortografica Luso-Brasileira de 1945)",
   "Portuguese Language Orthographic Agreement of 1990 (Acordo Ortográfico da Língua Portuguesa de 1990)" =>
   "Portuguese Language Orthographic Agreement of 1990 (Acordo Ortografico da Lingua Portuguesa de 1990)",
   "Niçard"                           => "Nicard",
   "Provençal"                       => "Provencal",
};

$Data{'langvar'}{'iana'}{'ignore'} = {
};

1;

# Local Variables:
# mode: cperl
# indent-tabs-mode: nil
# cperl-indent-level: 3
# cperl-continued-statement-offset: 2
# cperl-continued-brace-offset: 0
# cperl-brace-offset: 0
# cperl-brace-imaginary-offset: 0
# cperl-label-offset: 0
# End:

