#!/usr/bin/perl -w
# Copyright (c) 2011-2018 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

$Data{'langext'}{'link'} = [];

################################################################################

$Data{'langext'}{'iana'}{'orig'}{'name'} = {
   "Lengua de señas catalana"        => "Lengua de senas catalana",
   "finlandssvenskt teckenspråk"     => "finlandssvenskt teckensprak",
   "Lengua de Señas Panameñas"       => "Lengua de Senas Panamenas",
   "Lengua de Señas del Paraguay"    => "Lengua de Senas del Paraguay",
   "Türk İşaret Dili"                => "Turk Isaret Dili",
   "Urubú-Kaapor Sign Language"      => "Urubu-Kaapor Sign Language",
   "Yolŋu Sign Language"             => "Yolnu Sign Language",
   "Yan-nhaŋu Sign Language"         => "Yan-nhanu Sign Language",
};

$Data{'langext'}{'iana'}{'ignore'} = {
};

1;

# Local Variables:
# mode: cperl
# indent-tabs-mode: nil
# cperl-indent-level: 3
# cperl-continued-statement-offset: 2
# cperl-continued-brace-offset: 0
# cperl-brace-offset: 0
# cperl-brace-imaginary-offset: 0
# cperl-label-offset: 0
# End:

